@@ -87,4 +87,18 @@ Test(b32_decode_test, b32_decode_input_whitespaces) {
     unsigned char *dk = base32_decode(k, strlen(k), &err);
 
     cr_expect_str_eq(dk, expected, "%s");
-}
\ No newline at end of file
+}
+
+Test(b32_decode_test, b32_decode_encode_null) {
+    const char* token = "LLFTSZYMUGKHEDQBAAACAZAMUFKKVFLS";
+    baseencode_error_t err;
+
+    unsigned char* binary = base32_decode(token, strlen(token)+1, &err);
+    cr_expect_eq(err, SUCCESS);
+
+    char* result = base32_encode(binary, 20, &err);
+    cr_expect_eq(err, SUCCESS);
+
+    cr_expect_str_eq(result, token, "%s");
+}
+
